package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````\I@$"#0```!PP@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(0*\`
M`$"O```%`````!````$```#XO@``^$X%"/A.!0@L`@``G!(```8`````$```
M`@````2_```$3P4(!$\%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&2`H```@"`%"(`@!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D^+X`
M`/A.!0CX3@4("`$```@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`LJ!-)79"\D!+F2H`<85=%L=.<D0E````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M5```````````````50```%8```!9``````````````!:````7````%T```!?
M`````````&$```!C``````````````!E````9@```&<`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````X`(`````````````$@```(8#
M`````````````!(````D`@`````````````2````$0``````````````(```
M`/0#`````````````!(```!W`P`````````````2````/0$`````````````
M$@```/L"`````````````!(```#3```````````````2````YP(`````````
M````$@```*\``````````````!(````X`0`````````````2````G@(`````
M````````$@```#0#`````````````!(```"O`@`````````````2````H0$`
M````````````$@```$0#`````````````!(````[`P`````````````2````
M80$`````````````$@```.$``````````````!(```#K`0`````````````2
M````B`$`````````````$@```&T"`````````````!(````<`@``````````
M```2````RP(`````````````$@```-@!`````````````!(```"\`@``````
M```````2````Y`$`````````````$@```&\!`````````````!(```!+`P``
M```````````2````+0``````````````(````'\"`````````````!(```!8
M`P`````````````2````>```````````````$@```-D"`````````````!(`
M``"-`P`````````````2````%0(`````````````$@````\!````````````
M`!(```"^```````````````2````E@$`````````````$@```+8"````````
M`````!(```",`@`````````````2````/0(`````````````$@```,0"````
M`````````!(```!J```````````````2````0@$`````````````$@````(#
M`````````````!(```#-`0`````````````2````'`$`````````````$@``
M`'\#`````````````!(```#2`@`````````````2````KP$`````````````
M$@```#P``````````````"````#S```````````````2````?P$`````````
M````$@```%\#`````````````!(```#M`@`````````````2````AP``````
M````````$@```%```````````````"````"$`@`````````````2````(P,`
M````````````$@```"D"`````````````!(````0`P`````````````2````
M3@(`````````````$@```)4"`````````````!(````;`P`````````````2
M````:0,`````````````$@```$X!```PE00(`````!(```!L!```F-\$"`0`
M```1`!``(@0``"#.!`A!#```$@`.`',$``"0R@0(MP$``!(`#@#+`P``A-\$
M"``````2``\`H0,``$!1!0@$````(0`:`-$#``"@QP0(!0```!(`#@!2!```
M(-\$"%T````2``X`G@```."5!`@`````$@```"T!``!0404(!````!$`&@`O
M!```%%$%"``````0`!D`+0,``$A1!0@$````$0`:`#$$```4404(`````"``
M&0"@`P``0%$%"`0````A`!H`P0,``(#?!`@"````$@`.`&($```@404(!```
M`!$`&0"(!```L,<$"+@!```2``X``@$``%11!0@!````$0`:`)\#``!`404(
M!````!$`&@":`P``T)8$""("```2``X`IP0``%#,!`AI````$@`.`.(#``#`
MS`0()````!(`#@#]`P``0-X$"&D````2``X`L`,``"11!0@`````$``:`+P#
M``"4804(`````!``&@!>`@``G-\$"`0````1`!``T00``'#:!`C.`P``$@`.
M`#P$``#@Q@0(L0```!(`#@`U!```\I@$"``````2``X`O0$``""3!`@`````
M$@```!8$``"@R00(YP```!(`#@"I`P``)%$%"``````0`!D`"00``'#)!`@B
M````$@`.`+4$``"PW@0(.````!(`#@"`!```8,8$""<````2``X`]@$``%A1
M!0@3````$0`:`)4$``#PS`0()@$``!(`#@""!```;)($"``````2``L``&QI
M8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R
M;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?
M8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T
M<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R
M7W!L`%]F<%]H=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N
M,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT
M``````(``@`#`````@`"``(``@````(```````0``@`"`````@`"````````
M````!0`&``(````"``(````'`````@`"`````@`"``8``````````@`"``,`
M`@``````!P```````@`"````````````"``'```````"``@``P`(``,``@`"
M``<````!``$``0`!``(``0`!```````!``(``0`"``$``0`!`````@`!``$`
M`0`!``$``0`!``$``0`!`````0`!``$``0`!`````0`!`````0`"``4"```0
M````,````!)I:0T```8`YP0``!`````0:6D-```#`/$$`````````0`%`%0"
M```0`````````!)I:0T```@`YP0``!````!T&6D)```'`/L$```0````<AEI
M"0``!0`'!0``$````!1I:0T```0`$P4``!`````0:6D-```"`/$$````````
M_$\%"`8?``!`404(!58``$A1!0@%3P``4%$%"`5-``!4404(!54``%A1!0@%
M9P``#%`%"`<!```04`4(!P(``!10!0@'`P``&%`%"`<%```<4`4(!P8``"!0
M!0@'!P``)%`%"`<(```H4`4(!PD``"Q0!0@'80``,%`%"`<*```T4`4(!PL`
M`#A0!0@'#```/%`%"`<-``!`4`4(!PX``$10!0@'#P``2%`%"`<0``!,4`4(
M!Q$``%!0!0@'$@``5%`%"`<3``!84`4(!Q0``%Q0!0@'%0``8%`%"`<6``!D
M4`4(!Q<``&A0!0@'&```;%`%"`<9``!P4`4(!QH``'10!0@'&P``>%`%"`<<
M``!\4`4(!QT``(!0!0@''@``A%`%"`<@``"(4`4(!R$``(Q0!0@'(@``D%`%
M"`<C``"44`4(!R0``)A0!0@')0``G%`%"`<F``"@4`4(!R<``*10!0@'*```
MJ%`%"`<I``"L4`4(!RH``+!0!0@'1```M%`%"`<K``"X4`4(!RP``+Q0!0@'
M+0``P%`%"`<N``#$4`4(!R\``,A0!0@',```S%`%"`<Q``#04`4(!S(``-10
M!0@',P``V%`%"`<T``#<4`4(!TP``.!0!0@'-@``Y%`%"`<W``#H4`4(!S@`
M`.Q0!0@'.0``\%`%"`<Z``#T4`4(!SP``/A0!0@'/0``_%`%"`<^````404(
M!S\```11!0@'0```"%$%"`=!```,404(!T(``!!1!0@'0P``4X/L".BK!@``
M@<.+O0``BX/\____A<!T!>@V!```@\0(6\,`_S4$4`4(_R4(4`4(`````/\E
M#%`%"&@`````Z>#_____)1!0!0AH"````.G0_____R444`4(:!````#IP/__
M__\E&%`%"&@8````Z;#_____)1Q0!0AH(````.F@_____R4@4`4(:"@```#I
MD/____\E)%`%"&@P````Z8#_____)2A0!0AH.````.EP_____R4L4`4(:$``
M``#I8/____\E,%`%"&A(````Z5#_____)310!0AH4````.E`_____R4X4`4(
M:%@```#I,/____\E/%`%"&A@````Z2#_____)4!0!0AH:````.D0_____R5$
M4`4(:'````#I`/____\E2%`%"&AX````Z?#^____)4Q0!0AH@````.G@_O__
M_R504`4(:(@```#IT/[___\E5%`%"&B0````Z<#^____)5A0!0AHF````.FP
M_O___R5<4`4(:*````#IH/[___\E8%`%"&BH````Z9#^____)610!0AHL```
M`.F`_O___R5H4`4(:+@```#I</[___\E;%`%"&C`````Z6#^____)7!0!0AH
MR````.E0_O___R5T4`4(:-````#I0/[___\E>%`%"&C8````Z3#^____)7Q0
M!0AHX````.D@_O___R6`4`4(:.@```#I$/[___\EA%`%"&CP````Z0#^____
M)8A0!0AH^````.GP_?___R6,4`4(:``!``#IX/W___\ED%`%"&@(`0``Z=#]
M____)910!0AH$`$``.G`_?___R684`4(:!@!``#IL/W___\EG%`%"&@@`0``
MZ:#]____):!0!0AH*`$``.F0_?___R6D4`4(:#`!``#I@/W___\EJ%`%"&@X
M`0``Z7#]____):Q0!0AH0`$``.E@_?___R6P4`4(:$@!``#I4/W___\EM%`%
M"&A0`0``Z4#]____);A0!0AH6`$``.DP_?___R6\4`4(:&`!``#I(/W___\E
MP%`%"&AH`0``Z1#]____)<10!0AH<`$``.D`_?___R7(4`4(:'@!``#I\/S_
M__\ES%`%"&B``0``Z>#\____)=!0!0AHB`$``.G0_/___R744`4(:)`!``#I
MP/S___\EV%`%"&B8`0``Z;#\____)=Q0!0AHH`$``.F@_/___R7@4`4(:*@!
M``#ID/S___\EY%`%"&BP`0``Z8#\____)>A0!0AHN`$``.EP_/___R7L4`4(
M:,`!``#I8/S___\E\%`%"&C(`0``Z5#\____)?10!0AHT`$``.E`_/___R7X
M4`4(:-@!``#I,/S___\E_%`%"&C@`0``Z2#\____)0!1!0AHZ`$``.D0_/__
M_R4$404(:/`!``#I`/S___\E"%$%"&CX`0``Z?#[____)0Q1!0AH``(``.G@
M^____R40404(:`@"``#IT/O___\E_$\%"&:0``````````"-3"0$@^3P_W'\
M58GE5E-1B<N#[$"+002)1=2+00B)1=!EH10```")1>0QP(U%T%"-1=104>B6
M_?__@\0,:#"5!`AH,)4$"&C@E00(Z,]'``"#Q!"`/511!0@`=3'HKOS__X7`
MHY!A!0@/A*D!``"#[`Q0Z/C[__]9_S50404(Z`S___^#Q!#&@!T%````@^P,
M_S50404(Z/3^__^`B,X"```"6O\U4%$%".CA_O__@(C.`@```8L#@\00QT7$
M`````(/`!8E%P-]MP-@%<"`%"-T%>"`%"-G)W^G=V`^'`P$``(/L#,'@`E#H
M<?S__XMUU(L;@\00HX1A!0C'!8AA!0@$````BQ:#^P''0`1[X00(QT`,?N$$
M"(D0BQ4@404(B5`(N@$```!^$Y"-="8`BPR6B4R0#(/"`3G:=?*#[`S'1)@,
M`````(/#`VH`4%-HD,8$"/\UD&$%".A@_?__@\0@A<")PW11@^P,_S60804(
MZ$G[__^-5>"X/^`$".B<)@``@\00A<!T1(/L#/\UD&$%".CG^O__Z/+\__^#
MQ!")V(MUY&4S-10```!U9(UE]%E;7EV-8?S#@^P,_S60804(Z&C]__^#Q!")
MP^N:H8QA!0B%P'0?@^P,4.B/10``@\00ZZ504&A8404(:._?!`CH*?S__XU5
MX+CTWP0(Z!PF``"%P*.,804(#X1Z____Z\7H>/K__X/L#&H!Z([[__\Q[5Z)
MX8/D\%!44FB`WP0(:"#?!`A15FC0E@0(Z*W[___T9I!FD&:09I!FD&:0BQPD
MPV:09I!FD&:09I!FD+@G404(+211!0B#^`9V&K@`````A<!T$56)Y8/L%&@D
M404(_]"#Q!#)\\.0C70F`+@D404(+211!0C!^`*)PL'J'P'0T?AT&[H`````
MA=)T$E6)Y8/L$%!H)%$%"/_2@\00R?/#C70F`(V\)P````"`/6M1!0@`=1-5
MB>6#[`CH?/___\8%:U$%"`')\\-FD+@`3P4(BQ"%TG4%ZY.-=@"Z`````(72
M=/)5B>6#[!10_]*#Q!#)Z77___]FD&:0D%57C6@X5E.![`P#``")1"0\C80D
M@````(E\)`QEBQ44````B90D_`(``#'2B>^)="0(B<6-="8`BP>+5P0QV\=%
M_`````"#Q1"#QP@/R(G6B=&)1>B)T,'F&,'@"(G:)0``_P`)\(G&B<@/K-`8
MP>H8"<:)R(D4)`^LV`@E`/\```GPB47PBP0DB47TC80D``$``#GH=:&-A"3@
M````C90DX`(``(UV`(L8BT@$@\`(,UC0,TC4,UB@,TBD,UB0,TB4QT`4````
M`(G>B<^)V0'QB?N)#"2)\0^L^1\+#"0/I/,!B5PD!(E($#G0=;J+1"0\BSB+
M:`2+<!B)^HMX"(GIBV@,B70D"(G+BW`@B4PD%(G1B7PD&(MX$(EL)!R+:!2)
M="18B=:)5"00B3PDBW@<P>8%#ZS9&XEL)`2)]3'2B7PD#(MX)`G-BW0D6`-T
M)'B)Z(E\)%R+?"1<$WPD?(GQ@<&9>8):B?N#TP`!R(M,)!@1VHL<)(E$)"")
M5"0DBU0D"(G=,=6)[R'/B?J+?"0(,?J+?"0@BT0D&(L<)(M,)!#'1"0D````
M`,=$)#0``````=>+5"0<B<:)?"0HB7PD((G'P>8>#ZS7`HGUBW0D"`G]`[0D
M@````(M\)`P3O"2$````B6PD,(GPBW0D!`69>8):B?J)WX/2`#'O(W0D%"'/
M,SPD,W0D!(GYB?,!P8M$)"`1TXM4)"2)3"1`B5PD1(M<)$")Q@^LT!N+5"04
MP>8%B<&+1"00"?$!RS'_B<&)WHE<)%`/K-`"P>$>"<&+1"0HB4PD0#'I(<B)
MPHL$)#'J`X0DB````(G1!9EY@EH!P8GPP>`%B40D*(GPBVPD*`^L^!N+5"0D
MQT0D+`````")1"1("VPD2(M$)"#'1"0D``````'IB4PD*(E,)&")P<'A'@^L
MT`*+5"1`B<T)Q8M$)%");"1(B=,QZR'8,="+5"0LB<&+1"0P`X0DD`````69
M>8):`<&+1"0HP>`%B40D((M$)"B+;"0@#ZS0&XE$)#`+;"0PBT0D0`'IB4PD
M((E,)%")\<'A'@^L_@*)RXN,))@```"+?"1("?.+="1@B=J)7"1`@<&9>8):
M`<$Q^HM$)"`AUHM4)"2)]3']B<8!Z<'F!0^LT!N)1"0PBVPD,(M$)"B+5"0L
MQT0D-`````#'1"0L``````GUBW0D0`'IB4PD8(E,)#")P<'A'HGU#ZS0`HN4
M)*````")RPG#BT0D2(E<)$"!PIEY@EJ)T8M4)#0!P3'=B>B+;"10(<6+1"0P
MB>\Q]P'YP>`%B<>+1"0P#ZS0&XM4)"3'1"0D`````(E$)"@+?"0HBT0D(`'Y
MBWPD0(E,)"B)3"10B<$/K-`"BY0DJ````,'A'HG-"<6!PIEY@EJ);"1(B=&)
M^@'Q,>HC5"1@B=4Q_8M\)"@!Z8ML)"R)^,'@!8E$)"")^`^LZ!N+;"0@"<4!
MZ8E,)&")3"0@BWPD,(ML)#2+1"1`QT0D-`````")^HG^BWPD2,'B'HG3BY0D
ML`````^L[@()\X'"F7F"6HMT)%")T8G:B5PD0`'!,?J+1"0@(=:+5"0DB?4Q
M_8G&`>G!Y@4/K-`;BU0D+(G+QT0D+`````")1"0PBT0D*(ML)#")P0GUBW0D
M0`'KP>$>#ZS0`HN4)+@```")7"0PB?6)7"10B<L)PXM$)$B!PIEY@EJ)7"1`
MB=&+5"0T`<$QW8GHBVPD8"'%BT0D,(GO,?<!^<'@!8G'BT0D,`^LT!N+5"0D
MB40D*`M\)"B+1"0@`?F)3"1@B4PD*(G!#ZS0`HN4),````#!X1Z+?"1`B<W'
M1"0D``````G%@<*9>8):B6PD2(G1B?H!\3'J(U0D4(G5,?V+?"0H`>F+;"0L
MB?C!X`6)1"0@B?B+?"0P#ZSH&XML)"")^HG^BWPD2`G%BT0D0`'IBVPD-,'B
M'HG3BY0DR````(E,)%")3"0@QT0D-``````/K.X""?.!PIEY@EJ+="1@B=&)
MVHE<)$`!P3'ZBT0D("'6BU0D)(GU,?V)Q@'IP>8%#ZS0&XM4)"R)1"0PBVPD
M,(M$)"@)]8MT)$`!Z8E,)#")3"1@B<'!X1Z)]0^LT`*+E"30````B<L)PXM$
M)$B)7"1`@<*9>8):B=$!P3'=B>B+;"10(<6+1"0PB>\Q]P'YP>`%B<>+1"0P
MBU0D-,=$)"P`````#ZS0&XM4)"3'1"0D`````(E$)"@+?"0HBT0D(`'YBWPD
M0(E,)%")3"0HB<$/K-`"BY0DV````,'A'HG-"<6!PIEY@EJ);"1(B=&)^@'Q
M,>HC5"1@B=4Q_8M\)"@!Z8ML)"R)^,'@!8E$)"")^(M\)#`/K.@;BVPD((GZ
MB?Z+?"1("<6+1"1``>F+;"0TP>(>B=.+E"3@````B4PD((E,)&`/K.X""?.!
MPIEY@EJ+="10B=&)VHE<)$`!P3'ZBT0D("'6BU0D)(GU,?V)Q@'IP>8%#ZS0
M&XG+B40D,(ML)#`)]0'KB5PD4(E<)#"+1"0HBU0D+(MT)$#'1"0T`````,=$
M)"P`````B<'!X1Z)]0^LT`*)RXN,).@```"+5"0T"<.+1"1(B5PD0('!F7F"
M6@'!,=V)Z(ML)&`AQ8M$)#")[S'W`?G!X`6)QXM$)#`/K-`;BU0D),=$)"0`
M````B40D*`M\)"B+1"0@`?F+?"1`B4PD*(E,)&")P<'A'HG-BXPD\`````^L
MT`*)^@G%@<&9>8):`?$QZB-4)%");"1(B=4Q_8M\)"@!Z8ML)"R)^,'@!8E$
M)"")^(M\)#`/K.@;BVPD((GZB?X)Q0'IBVPD-,'B'HG3BY0D^````(E,)%")
M3"0@BT0D0`^L[@*+?"1(QT0D-``````)\X'"F7F"6HMT)&")T8G:B5PD0`'!
M,?J+1"0@(=:+5"0DB?4Q_8G&`>G!Y@4/K-`;BU0D+,=$)"P`````B40D,(ML
M)#"+1"0H"?6+="1``>F)3"0PB4PD8(G!P>$>B?4/K-`"BY0D``$``(G+"<.+
M1"1(B5PD0('"F7F"6HG1BU0D-`'!,=V)Z(ML)%`AQ8M$)#")[S'W`?G!X`6)
MQXM$)#`/K-`;BU0D)(E$)"@+?"0HBT0D(`'YBWPD0(E,)%")3"0HB<$/K-`"
MBY0D"`$``,'A'HG-"<6!PIEY@EJ);"1(B=&)^@'Q,>HC5"1@B=4Q_8M\)"C'
M1"0D``````'IBVPD+(GXP>`%B40D((GXBWPD,`^LZ!N+;"0@B?J)_@G%BT0D
M0`'IBVPD-,'B'HG3BY0D$`$``(E,)&")3"0@BWPD8`^L[@*+;"1(QT0D-```
M```)\X'"F7F"6HG1BU0D2(E<)$`!P8M$)%`QVB'0BU0D)#'%BT0D(`'IB<N)
MQ@^LT!N+5"0LP>8%B40D,(M$)"B+;"0PB<$)]0'KP>$>BVPD0`^LT`*)7"0P
MB5PD4(G+BY0D&`$```G#BT0D2('"H>O9;@'0,=V+5"0T,>^)^0'!BT0D,,'@
M!8G'BT0D,`^LT!N)1"0HBVPD*(M$)""+5"0DB5PD2,=$)"P`````"?W'1"0D
M``````'IB4PD8(E,)"B)P<'A'HM\)"@/K-`"B<V+E"0@`0``"<6+1"1`B6PD
M0('"H>O9;@'0,>N+;"10,=V)Z8ML)"P!P8GXP>`%B40D((GXBWPD,`^LZ!N+
M;"0@B?J)_HM\)&`)Q8M$)$@!Z8ML)#3!XAZ)3"0@B4PD4`^L[@*)U8N4)"@!
M```)]8EL)$B!PJ'KV6X!T#-L)$"+5"0D,>^)^0'!BT0D((G&#ZS0&\'F!8M4
M)"R)1"0PBVPD,(M$)"@)]0'I,?^)SHE,)&")P<'A'@^LT`*)RPG#B5PD,(N4
M)#`!``"+C"0T`0``BT0D0(ML)$B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$
M)"B)5"0LBU0D4(GPBUPD,,=$)"P`````,>J)T0-,)"C!X`6)1"0HB?"+;"0H
M#ZSX&XM4)"2)1"1`"VPD0(M$)"`!Z8E,)"B)3"10B<'!X1X/K-`"B<V+E"0X
M`0``"<6+1"1(B6PD0('"H>O9;@'0,>N+;"1@BU0D+#'=B>D!P8M$)"C!X`6)
M1"0@BT0D*(ML)"`/K-`;B?*)1"1("VPD2`'IP>(>B4PD8(G5B4PD((N4)$`!
M``"+1"0P#ZS^`HM\)%#'1"0D``````GU@<*AZ]ENQT0D-``````!T(EL)$@S
M;"1`BU0D)#'OB?F+?"1@`<&+1"0@B<N)Q@^LT!N+5"0LP>8%QT0D+`````")
M1"0PBT0D*(ML)#")P0GU`>O!X1Z+;"1(#ZS0`HE<)#")7"10B<N+E"1(`0``
M"<.+1"1`@<*AZ]EN`=`QW8M4)#0Q[XGY`<&+1"0PP>`%B<>+1"0P#ZS0&XM4
M)"2)1"0H"WPD*(M$)"`!^8E,)&")3"0HB<'!X1X/K-`"B<V+E"10`0``"<6+
M1"1(B5PD2(EL)$"+?"0H@<*AZ]ENQT0D)``````!T#'KBVPD4#'=B>F+;"0L
M`<&)^,'@!8E$)"")^(M\)#`/K.@;BVPD((GZB?Z+?"1@"<6+1"1(`>F+;"0T
MP>(>B4PD4(E,)"`/K.X"B=6+E"18`0``"?6);"1(@<*AZ]EN`=`S;"1`BU0D
M)#'OB?D!P8M$)"")Q@^LT!O!Y@6+5"0LB40D,(ML)#"+1"0H"?4!Z3'_BVPD
M2(G.B4PD8(G!P>$>#ZS0`HN4)&`!``")RXN,)&0!```)PXM$)$")7"0P@<*A
MZ]EN@]$`B<N)T3'2`<@1VC-L)#")1"0HB50D+(M4)%")\#'JB=$#3"0HP>`%
MB40D*(GPBVPD*`^L^!N+5"0DBUPD,(E$)$`+;"1`BT0D(,=$)"P`````QT0D
M)``````!Z8E,)"B)3"10B<'!X1X/K-`"B<V+E"1H`0``"<6+1"1(B6PD0('"
MH>O9;@'0,>N+;"1@BU0D+#'=B>D!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;
MB?*)1"1("VPD2(M$)#`!Z<'B'HG5BY0D<`$``(E,)"`/K/X"BWPD4(E,)&`)
M]8'"H>O9;@'0B6PD2#-L)$"+5"0D,>^)^0'!BT0D((G+B<8/K-`;P>8%B40D
M,(M$)"B+;"0PBU0D+(M\)&#'1"0T`````(G!QT0D+``````)]0'KP>$>BVPD
M2`^LT`*)7"10B5PD,(G+BY0D>`$```G#BT0D0('"H>O9;@'0,=V+5"0T,>^)
M^0'!BT0D,,'@!8G'BT0D,`^LT!N+5"0DQT0D)`````")1"0H"WPD*(M$)"`!
M^8E,)"B)3"1@B<'!X1Z+?"0H#ZS0`HG-BY0D@`$```G%BT0D2(E<)$B);"1`
M@<*AZ]EN`=`QZXML)%`QW8GIBVPD+`'!B?C!X`6)1"0@B?@/K.@;BVPD(`G%
M`>F)3"10B4PD((M\)#"+;"0TBT0D2(GZB?Z+?"1@P>(>#ZSN`HG5BY0DB`$`
M``GUB6PD2('"H>O9;@'0,VPD0(M4)"0Q[XGY`<&+1"0@B<8/K-`;P>8%BU0D
M+(E$)#"+;"0PBT0D*`GU`>DQ_XML)$B)SHE,)&")P<'A'@^LT`*+E"20`0``
MB<N+C"24`0``"<.+1"1`B5PD,('"H>O9;H/1`(G+B=$QT@'($=HS;"0PB40D
M*(E4)"R+5"10B?#'1"0L`````#'JB=$#3"0HP>`%B40D*(GPBVPD*`^L^!N)
M1"1`"VPD0`'IB4PD4(E,)"B+1"0@BU0D)(M<)##'1"0D`````,=$)#0`````
MB<'!X1X/K-`"B<V+E"28`0``"<6+1"1(B6PD0('"H>O9;@'0,>N+;"1@BU0D
M+#'=B>D!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B?*)1"1("VPD2(M$)#`!
MZ<'B'HG5BY0DH`$``(E,)"`/K/X"BWPD4(E,)&`)]8'"H>O9;@'0B6PD2#-L
M)$"+5"0D,>^)^0'!BT0D((G+B<8/K-`;BU0D+,'F!8E$)#"+1"0HBVPD,(G!
M"?4!Z\'A'@^LT`*)7"10B5PD,(G+BY0DJ`$```G#BT0D0(ML)$B+?"1@QT0D
M+`````")7"1@@<*AZ]EN`=`QW8M4)#0Q[XGY`<&+1"0PP>`%B<>+1"0P#ZS0
M&XM4)"3'1"0D`````(E$)"@+?"0HBT0D(`'YBWPD4(E,)$")3"0HB<'!X1X/
MK-`"B<V+E"2P`0``B=D)Q8M$)$B)[H'"H>O9;HGSB70D:`'0,>F+;"0L,<^+
M5"0TB?F+?"0H`<&)^,'@!8E$)"")^`^LZ!N+;"0@B40D2`ML)$B+1"0P`>F)
MQXE,)$B)3"0@B<$/K-<"P>$>BT0D0(GRB<T)_3'_">LAZHEL)$`AV(G!"=&)
MSHN,)+@!``"+G"2\`0``BT0D8('!W+P;CX/3`#'2`<B)\1':B?L!P8M$)""+
M?"0L$=.+5"0DB4PD,(E<)#3'1"0T`````(G&QT0D+``````/K-`;P>8%B<$)
M\8MT)"B)R(M,)#`!P8M$)$B)3"10B4PD,(GQP>$>#ZS^`HG/"?>+="1`B?N)
M^HE\)$B+?"0D"?,A\B'8B<&+1"1H"=&+E"3``0``B<Z)\X'"W+P;CP'0BU0D
M-`'#BT0D,(G&#ZS0&\'F!8E$)"B+;"0HBT0D4`GUBW0D(`'KB5PD*(E<)&")
M\<'A'@^L_@*+?"1(B<L)\XG:B?N)^8E4)%`)TR'1(=B)Q8M$)$`)S8N,),@!
M``"!P=R\&X\!R(GI`<&+1"0HBU0D+(M\)#3'1"0D`````,=$)#0`````B<8/
MK-`;P>8%BU0D4`G&BT0D8`'QBW0D,(E,)&B)3"0@B=.)\<'A'@^L_@*)S8M\
M)"S'1"0L``````GU">LAZHEL)$`AV(G!BT0D2`G1BY0DT`$``(G.B?.!PMR\
M&X\!T(M4)"0!PXM$)"")Q@^LT!O!Y@6)1"0PBVPD,(M$)&@)]8MT)"@!ZXE<
M)#")7"1@B?&+7"1`#ZS^`L'A'HG/BXPDV`$```GWB?J)?"1("=HAT(GZB<6+
M1"10(=H)U8'!W+P;CXM4)#0!R(GI`<&+1"0PB<8/K-`;P>8%B40D*(ML)"@)
M]0'IB4PD:(E,)"B+="0@BWPD)(M$)&#'1"0D`````(GQP>$>#ZS^`HM\)$B)
MRXN,).`!```)\XG:B?N)5"10"=,AV(G[BWPD-(G%BT0D0"'3"=V!P=R\&X^+
M5"0LB>L!R`'#BT0D*(G&#ZS0&\'F!8M4)%`)QHM$)&@!\XMT)#")7"1@B5PD
M((N<).P!``")\<'A'@^L_@*)S8G1,?\)]0GI(>J);"1`(<B)P8M$)$@)T8G.
MBXPDZ`$``('!W+P;CX/3`#'2`<B)\1':B?L!P8M$)""+?"0L$=.+5"0DB4PD
M,(E<)#2+7"1`B<;'1"0T``````^LT!O!Y@6)P0GQBW0D*(G(BTPD,`'!BT0D
M8(E,)&B)3"0PB?'!X1X/K/X"B<\)]XGZB7PD2,=$)"P`````"=HAT(GZBWPD
M)"':B<&+1"10"=&+E"3P`0``QT0D)`````")SHGS@<+<O!N/`="+5"0T`<.+
M1"0PB<8/K-`;P>8%B40D*(ML)"B+1"1H"?6+="0@`>N)7"1@B5PD*(GQP>$>
M#ZS^`HM\)$B)RPGSB=J)^XGYB50D4`G3(=&+5"0L(=B+?"0TB<6+1"1`"<V+
MC"3X`0``@<'<O!N/`<B)Z0'!BT0D*(G&#ZS0&\'F!8M4)%`)QHM$)&`!\8MT
M)#")3"0@B4PD:(G3B?'!X1X/K/X"B<T)]0GK(>J);"1`(=B)P8M$)$@)T8N4
M)``"``")SHGS@<+<O!N/`="+5"0D`<.+1"0@B<8/K-`;P>8%B40D,(ML)#`)
M]0'KB5PD8(MT)"B+?"0LB5PD,(M<)$"+1"1HB?''1"0T`````,=$)"P`````
M#ZS^`L'A'HG/BXPD"`(```GWB?J)?"1("=HAT(GZBWPD)(G%BT0D4"':"=6!
MP=R\&X^+5"0TQT0D)``````!R(GI`<&+1"0PB<8/K-`;P>8%B40D*(ML)"B+
M1"1@"?6+="0@`>F)3"1HB4PD*(GQP>$>#ZS^`HM\)$B)RXN,)!`"```)\XG:
MB?N)5"10"=,AV(G[BWPD-(G%BT0D0"'3"=V!P=R\&X^+5"0L`<B)Z0'!BT0D
M*(G+B<8/K-`;P>8%BU0D4`G&BT0D:`'SBW0D,(E<)&")7"0@B?'!X1X/K/X"
MB<V)T3'_"?4)Z2'JB6PD0"'(BYPD'`(``(G!BT0D2`G1B<Z+C"08`@``@<'<
MO!N/@],`,=(!R(GQ$=J)^P'!BT0D((M\)"P1TXM4)"2)3"0PB5PD-(M<)$")
MQL=$)#0`````QT0D+``````/K-`;P>8%B<$)\8MT)"B)R(M,)#`!P8M$)&")
M3"1HB4PD,(GQP>$>#ZS^`HG/"?>)^HE\)$@)VB'0B?J+?"0D(=J)P8M$)%`)
MT8N4)"`"``")SHGS@<+<O!N/`="+5"0T`<.+1"0PB<8/K-`;P>8%B40D*(ML
M)"B+1"1H"?6+="0@`>N)7"1@B5PD*(GQP>$>#ZS^`HM\)$B)RPGSB=J)^XGY
MB50D4`G3(=$AV(G%BT0D0`G-BXPD*`(``('!W+P;CP'(B>D!P8M$)"B+5"0L
MBWPD-,=$)"0`````QT0D-`````")Q@^LT!O!Y@6+5"10"<:+1"1@`?&+="0P
MB4PD:(E,)"")TXGQP>$>#ZS^`HG-BWPD+`GU">LAZHEL)$`AV(G!BT0D2`G1
MBY0D,`(``(G.B?.!PMR\&X\!T(M4)"0!PXM$)"")Q@^LT!O!Y@6)1"0PBVPD
M,(M$)&@)]8MT)"@!ZXE<)#")7"1@B?&+7"1`#ZS^`L'A'HG/BXPD.`(```GW
MB?J)?"1("=HAT(GZB<6+1"10(=H)U8'!W+P;CXM4)#0!R(GI`<&+1"0PB<8/
MK-`;P>8%B40D*(ML)"@)]0'IB4PD:(E,)"C'1"0L`````(MT)""+?"0DBT0D
M8,=$)"0`````B?'!X1X/K/X"BWPD2(G+BXPD0`(```GSB=J)^XE4)%`)TR'8
MB?N+?"0TB<6+1"1`(=,)W8'!W+P;CXM4)"P!R(GI`<&+1"0HB<N)Q@^LT!O!
MY@6+5"10"<:+1"1H`?.+="0PB5PD8(E<)""+G"1,`@``B?'!X1X/K/X"B<V)
MT3'_"?4)Z2'JB6PD0"'(B<&+1"1("=&)SHN,)$@"``"!P=R\&X^#TP`QT@'(
MB?$1VHG[`<&+1"0@BWPD+!'3BU0D)(E,)#")7"0TQT0D-`````")Q@^LT!O!
MY@6)P0GQBW0D*(G(BTPD,`'!BT0D8(E,)&B)3"0PB?'!X1X/K/X"B<L)\XMT
M)$")WXG:B5PD2(M<)$C'1"0L``````GW(?(A^(M\)"2)P8M$)%`)T8N4)%`"
M``")SHGQ@<+<O!N/`="+5"0T`<&+1"0PB<8/K-`;P>8%BY0D6`(``(E$)"B+
M;"0HBT0D0`GUBW0D(`'IBVPD:(E,)%")3"0HB?'!X1X/K/X"B<\)]X'"UL%B
MR@'0,?N+5"0L,=V)?"1`B>D!P8M$)"B)Q@^LT!O!Y@6+5"0T"<:+1"0P`?$Q
M_XG.B4PD8(G!P>$>#ZS0`HG-BY0D8`(```G%BT0D2(EL)#"+;"1`@<+6P6+*
M`=`S;"0P,VPD4(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D2`ML)$@!Z8E,
M)%")3"0@BT0D*(M4)"S'1"0D`````,=$)"P`````B<'!X1X/K-`"B<N+E"1H
M`@``"<.+1"1`B=V)7"1`BUPD,('"UL%BR@'0BU0D)#'KBVPD8#'=BYPD<`(`
M`(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XGRB40D2`ML)$B+1"0P`>G!
MXAX/K/X"B=6)3"0HB4PD8`GU@</6P6+*BU0D+(GOBVPD0`'8B7PD2#']B>Z+
M;"10,?6)Z0'!BT0D*(G+B<8/K-`;P>8%BU0D)`G&BT0D(`'S,?^)7"10B=Z)
MP<'A'@^LT`*)S8N4)'@"```)Q8M$)$");"0PBVPD2('"UL%BR@'0,VPD,(M4
M)"PS;"1@QT0D)`````#'1"0L`````(GI`<&)V,'@!8E$)"")V(ML)"`/K/@;
MB40D0`ML)$"+1"0H`>F)3"0@B4PD8(G!P>$>#ZS0`HG+BY0D@`(```G#BT0D
M2(G=B5PD0(M<)#"!PM;!8LH!T(M4)"0QZXML)%`QW8N<)(@"``")Z0'!BT0D
M(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$)$@+;"1(BT0D,`'IP>(>#ZS^`HG5
MB4PD*(E,)$@)]8'#UL%BRHGOBVPD0`'8B7PD,#']B>Z+;"1@,?6)Z0'!BT0D
M*(M4)"R+7"0PB<8/K-`;P>8%BU0D),=$)"0`````"<:+1"0@`?$Q_XG.B4PD
M4(G!P>$>#ZS0`HG-BY0DD`(```G%BT0D0(EL)$"!PM;!8LH!T#'KBVPD2(M4
M)"PQW8GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D2`ML)$B+1"0H`>F)3"0@
MB4PD8(G!P>$>#ZS0`HG-BY0DF`(```G%BT0D,(EL)$B!PM;!8LH!T#-L)$"+
M5"0D,VPD4(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XGRB40D,`ML)#`!
MZ8G]B?</K.\"P>(>B4PD4(E,)"B)^,=$)"P`````B=>+G"2@`@``"<>+;"1(
MBT0D0(M4)"R)?"1`@</6P6+*`=@Q_8GNBVPD8#'UB>D!P8M$)"B)RXG&#ZS0
M&\'F!8M4)"3'1"0D``````G&BT0D(`'S,?^)7"1@B=Z)P<'A'@^LT`*)S8N4
M)*@"```)Q8M$)$B);"0PBVPD0('"UL%BR@'0,VPD,(M4)"PS;"10B>D!P8G8
MP>`%B40D((G8BVPD(`^L^!N)1"1("VPD2(M$)"@!Z8E,)"")3"10B<'!X1X/
MK-`"B<N+E"2P`@``"<.+1"1`B=V)7"1`BUPD,('"UL%BR@'0,>N+;"1@,=V)
MZ0'!BT0D(,'@!8E$)"B+1"0@BU0D)(ML)"B+G"2X`@``QT0D+``````/K-`;
MB?*)1"1("VPD2(M$)#`!Z<'B'@^L_@*)U8E,)&")3"0H"?6!P];!8LJ+5"0L
MB>^+;"1``=B)?"1(,?V)[HML)%`Q]8GI`<&+1"0HB<8/K-`;P>8%BU0D)`G&
MBT0D(`'Q,?^)SHE,)%")P<'A'@^LT`*+E"3``@``B<V+C"3$`@``"<6+1"1`
MB6PD,(ML)$B!PM;!8LJ#T0")RXG1,=(!R!':,VPD,#';,VPD8(GI`<&)\!'3
MP>`%,=*)1"0@B?"+;"0@#ZSX&XE$)$`+;"1``>D1TXG*B50D0(E<)$2)5"0@
MQT0D)`````"+1"0HBU0D+,=$)"P`````B<'!X1X/K-`"BY0DR`(``(G+BXPD
MS`(```G#BT0D2(G=@<+6P6+*B6PD2(/1`(G+B=$QT@'($=J+7"0P,>N+;"10
M,=TQVXGI`<&+1"0@$=.+5"0DP>`%B40D*(M$)""+;"0H#ZS0&S'2B40D4`ML
M)%"+1"0P`>D1TXGRB4PD*`^L_@+!XAZ)7"1DBYPDT`(``(G5B4PD8`GUB[0D
MU`(``('#UL%BRHGOBVPD2(G9B7PD4(/6`#'2`<@1\C'],=N)[HML)$`Q]8GI
M`<&+1"0H$=.+5"0LB<8/K-`;P>8%,=()QHGPB=Z)RP'#BT0D(!'6BU0D)(E<
M)&B)="1L,?^)WHG!P>$>#ZS0`HG-"<6);"1`BY0DV`(``(M$)$B+;"10QT0D
M-`````#'1"0D`````('"UL%BR@'0,VPD0(M4)"PS;"1@B>D!P8G8P>`%B40D
M((G8BVPD(`^L^!N)1"0P"VPD,(M$)"@!Z8E,)#")3"1(B<'!X1X/K-`"BY0D
MX`(``(G+BXPDY`(```G#BT0D4(G=@<+6P6+*B6PD*(/1`(G+B=$QT@'($=J+
M7"1`,>N+;"1H,=TQVXGI`<&+1"0P$=.+5"0TP>`%B40D((M$)#"+;"0@#ZS0
M&S'2B40D4`ML)%`!Z1'3B<J)5"10B5PD5(E4)""+G"3H`@``B?*+1"1`P>(>
MBVPD*`^L_@*)UXM4)"0)]X'#UL%BR@'8,?V)?"1`B>Z+;"1(,?6)Z0'!BT0D
M((G&#ZS0&\'F!8M4)#0)QHGP`<@Q_XG&BT0D,(G!P>$>#ZS0`HG-BU0D((M,
M)"0)Q8M$)"B);"1@#Z31'L'B'HE4)#")3"0TBU0D((M,)"0/K,H"P>D"B4PD
M)(N,)/`"``")5"0@B?J!P=;!8LH!R(M,)$`QZ8ML)%`QS8GI`<&)\,'@!8E$
M)"B)\(ML)"@/K/@;#Z3R!8E$)$@+;"1(B50D+(GZP>H;B50D3(GH`<B)P0-,
M)!"+1"0\B</'0`0`````B0B+1"08BVPD,,=##`````#'0Q0`````QT,<````
M``'P"VPD(,=#)`````")0PB)Z`,$)(E#$(M$)&`#1"0(B4,8BT0D0`-$)%B)
M0R"+A"3\`@``93,%%````'4+@<0,`P``6UY?7</H?=3__XVV`````(V\)P``
M``"%P`^$FP```%575E.#[!R+#4!1!0B%R8E,)`AT50^V"(3)=%R`^3UT5XG#
M@\,!#[8+A,ET!8#Y/77Q*<.+3"0(BRF%[70LB50D#(G&B<]FD(/L!%-65>CU
MUO__@\00A<!U!X!\'0`]=!^#QP2++X7M==Z#Q!PQP%M>7UW#C70F`#';Z[B-
M="8`B?HK5"0(BT0D#,'Z`HD0@\0<C40=`5M>7UW#,<##C78`C;PG`````%.)
MPX/L&&6A%````(E$)`PQP(U4)`B)V.@S____A<!T.HVT)@````"+5"0(H4!1
M!0B-!)"+4`2%THD0=-6-=@"#P`2+4`2%THD0=?2-5"0(B=CH^?[__X7`=<V+
M1"0,93,%%````'4%@\086\/H3M/__XVT)@````"-O"<`````55>)QU93B=.#
M[#AEH10```")1"0H,<`QP(`Z/0^4P`'#4^AIU/__@\00B<6)^(U4)!CHF?[_
M_X7`#X0!`0``@^P,B<90Z$;4__^#Q!`YQ0^&TP```(M$)!B-#(4`````#[8'
MA,`/A(L!```\/0^$@P$``(GXZPZ)]HV\)P````"`^CUT"H/``0^V$(32=?$I
M^(U$*`*#[`R+-4!1!0A0`<[HBM/__X/$$(7`B08/A%8!``"A0%$%"(M4)!B-
M3P&+%)`/M@<\/8@"="&$P'4-ZQN-M"8`````/#UT$(/!`0^V0?^#P@&$P(@"
M=>S&`CTQP(VT)@`````/M@P#B$P"`8/``83)=?$QP(M\)!QE,ST4````#X7Y
M````@\0L6UY?7<.-M@````"#PP$/MD/_@\8!A,"(1O]U[^O,D(UT)@"+%4!1
M!0B+,H7V#X2M````,<#K!HUT)@")\(UP`8L,LH7)=?2-!(4,````BPV`804(
MA<ET,X/L"%!2Z*'2__^#Q!"%P*-`404(='Z-#+4`````QT2P!`````")="08
MZ;W^__^0C70F`(E4)`B#[`S'!8!A!0@!````4.AQTO__@\00A<!T0XT,M0``
M``"#[`11BU0D$(E,)!12B40D%%#HW-#__XM$)!B#Q!"+3"0,HT!1!0CKG#'`
MZ93^__^X"````#'VZ6+___^X_____^GV_O__Z"C1__^0C;0F`````%575E.)
MQH'LC````&6A%````(E$)'PQP(7V=`6`/@!U'XM$)'QE,P44````#X4?`0``
M@<2,````6UY?7<.-=@"#[`Q6Z!?4__^#Q!"%P(G'=,^-M@````"#[`Q7Z&_3
M__^#Q!"%P(G##X2Z````@'L3+@^$B````(/L#(UK$U;H[-'__XDL)(E$)!SH
MX-'__XM,)!R-1`$"B00DZ'#1__^)PUA:559HH-\$"&K_:@%3Z+O3__^#Q!R-
M1"0@4%-J`^A+T___@\00@_C_=!"+1"0L)0#P```]`$```'1K@^P,4^A:T/__
M@\00@^P,4^B^S___@\00Z5[___^-M@`````/MD,4A,`/A$S___\\+@^%9/__
M_X![%0`/A#K____I5?___Y"-="8`@^P,5^@?T___B30DZ+?/__^#Q!#IX/[_
M_XVT)@````")V.BQ_O__ZYCHRL___XUV`(V\)P````!64X/L$/\U4%$%".BP
MTO__BX"`````6XMP!/\U4%$%".B;TO__#[9895C_-5!1!0B#XW_HB-+__XM`
M!`^W0!#!X`<)PV:)7@)8_S50404(Z&S2__^+@(````"+6`18_S50404(Z%?2
M__^#Q`QJ`&AUX00(4.C'T/__B4,<6/\U4%$%".@XTO__BX"`````BU@$6/\U
M4%$%".@CTO__BX#0`P``B4,@6/\U4%$%".@.TO__BX"`````6HM8!/\U4%$%
M".CYT?__BXCP````@\00,=*%R70:@^P,_S50404(Z-S1__^+@/````"#Q!"+
M4'"#[`R)4R3_-5!1!0CHO]'__XN`@````(M`!,=`*`````!8_S50404(Z*/1
M__^+@(````"+0`3'0!@`````6O\U4%$%".B'T?__BX"`````68M8!/\U4%$%
M".ART?__BX#\`0``B4,L@\046U[#C78`4XG#@^P4_S50404(Z$_1__^#Q`P%
M_````%!3:@/H3M'__X/$$(7`=`>#Q`@QP%O#@^P,_S50404(Z"+1__^+@`P!
M``"#Q!`E`/```#T`0```=".#[`S_-5!1!0CH_]#__XN`#`$``(/$$"4`\```
M/0"@``!ULX/L"&H"4^@OT/__@\00A<`/E,"#Q`@/ML!;P^L-D)"0D)"0D)"0
MD)"0D%57B<=64XG5@>P@$```9:$4````B80D$!```#'`:/\/``"-="045FBF
MWP0(Z-_-__^#Q!"%P'Y@C5C_@'P<#`!T3HG#@^P$4VHO5NA@S___@\00A<!T
M08/L#/\U4%$%".A;T/__4U974.CBS___@\0@BX0D#!```&4S!10```!U-8'$
M'!```%M>7UW#C70F`(7;=;"-="8`@^P,_S50404(Z!K0__^#Q`Q55U#H;\W_
M_X/$$.N[Z`7-__^0C70F`(/L&/\U4%$%".CRS___:*CA!`AH(),$"&BUWP0(
M4.A]SO__@\0LPXGVC;PG`````(/L&/\U4%$%".C"S___B00DZ+K___]8_S50
M404(Z*[/__]:66H`:'7A!`AH=>$$"&APV@0(:-'?!`A0Z-#.__^#Q"S#C;8`
M````C;\`````5U93@>P0(```9:$4````B80D#"```#'`Z"/-__^#[`AHL=\$
M"%!HYM\$"&@!$```:@&-7"0F4^B4S___@\0@A<!X98/L!&@`$```C;PD$Q``
M`%=3Z'?,__^#Q!"%P(G&>$:-0`&#[`Q0Z`+-__^#Q!"%P(G#=#&#[`165U#H
MGLO__\8$,P"#Q!")V(N4)`P@``!E,Q44````=1&!Q!`@``!;7E_#C78`,<#K
MW^C/R___ZPV0D)"0D)"0D)"0D)"0Z3O___^-="8`C;PG`````%575E.!["P0
M``"+G"1`$```C50D&(N\)$00``!EH10```")A"0<$```,<"X]-\$".@+]___
M@^P(B<9J+U/HGLS__X/$$(7`="V)VKC]WP0(Z!OX__^)V(N4)!P0``!E,Q44
M````#X5(`0``@<0L$```6UY?7<.#[`Q3Z(',__]:68E$)!1H"N`$"%?H@,W_
M_X/$$(G%BT0D#(U\)!R#P`&)1"0,C70F`(7M=)V`?0``N/+?!`@/1.B%]G05
M@^P(55;H.LK__X/$$(7`#X2:````@^P,5>@FS/__@\00@'P%_R]U$XUT)@"#
MZ`&`?`7_+\9$!0``=/$#1"0,/?\/```/CT/___^#[`13:`S@!`A5:##A!`AH
M`!```&H!5^C>S?__@\04_S50404(Z(#-__^#Q`P%_````%!7:@/H7\W__X/$
M$(7`=2.#[`S_-5!1!0CH6LW__XN`#`$``(/$$"4`\```/0"```!T&8/L"&@*
MX`0(:@#HELS__X/$$(G%Z23___^#[`AJ`5?H<<S__X/$$(7`==6)^KC]WP0(
MZ,[V__^#[`Q7Z,7+__^#Q!#II/[__^CXR?__D(VT)@````"+1"0$#[8(A,ET
M%8U0`6:0@/DO#[8*#T3"@\(!A,EU\//#C;0F`````(V\)P````!3@^P8BUPD
M((7;=$0/MA.$TG0]B%0D#X/L#%/H\,K__XU$`_^#Q!`/ME0D#SG#<@_K2HVV
M`````(/H`3G#=$&`."]T].LOC78`C;PG`````(/L#&H"Z%;*__^#Q!"%P'1_
MNBX```!FB1"#Q!A;PV:0@#@O=#"#Z`$YPW+T.<-U)8#Z+W3+QT0D(`S@!`B#
MQ!A;Z>K*__^-=@"-O"<`````@#@O=0>#Z`$YPW+T*=B-4`*!^@`0``!W)X/`
M`6@`$```4%-H@%$%".@3R___@\00N(!1!0B#Q!A;PXVV`````(/$&#'`6\.)
M]HV\)P````!75H/L-&6A%````(E$)"PQP*&$X00(B40D"J&(X00(B40D#J&,
MX00(B40D$J&0X00(B40D%J&4X00(B40D&J&8X00(B40D'J&<X00(B40D(J&@
MX00(B40D)@^W!:3A!`AFB40D*K@.X`0(Z*'T__^X%^`$".B7]/__N!_@!`CH
MC?3__[@HX`0(Z(/T__^X+^`$".AY]/__N#_@!`CH;_3__[CTWP0(Z&7T__^X
M2^`$".A;]/__N%7@!`CH4?3__[A?X`0(Z$?T__^X_=\$".@]]/__N&G@!`CH
M,_3__[ARX`0(Z"GT__^-5"0$N'W@!`CH:_/__X7`=`R)PKA5X`0(Z(OT__^-
M5"0$N([@!`CH3?/__X7`=`R)PKB@X`0(Z&WT__^-5"0$N*O@!`CH+_/__X7`
M=#.)PKCTWP0(Z$_T__^ZU^`$"+@OX`0(Z$#T__^+1"0L93,%%````'55@\0T
M7E_#D(UT)@"-5"0$N+O@!`CHZO+__X7`=!:)PKA+X`0(Z`KT___KN9"-M"8`
M````C70D&[_,X`0(N0H```#SIG6?C50D);A+X`0(Z.#S___KC^@9Q___B?:-
MO"<`````@^P<9:$4````B40D##'`H1Q1!0B#^/]T%XM,)`QE,PT4````=3Z#
MQ!S#C;8`````C50D"+A+X`0(Z&+R__^%P'0>#[80@/HP#Y7`A-(/E<(/MM(A
MT*,<404(Z[V-="8`,<#K\>BGQO__C;0F`````(/L#.BHQO__@^P,4.C_Q?__
M@\00A<!T"(L`@\0,PV:0,<#K]HVV`````(V_`````%57O^/@!`A64[O9X`0(
M@^Q,BVPD8,=$)"#CX`0(C70D*&6A%````(E$)#PQP,=$)"39X`0(QT0D*.;@
M!`C'1"0LW.`$",=$)##AX`0(QT0D-//@!`C'1"0X`````.LCD(/L"%50B40D
M&.A"Q?__@\00A<!T2X7;="J+!HG?@\8$B<.-5"0<B?CH<_'__X7`=`6`.`!U
MRHGJB?CHD?+__X7;==:+1"0\93,%%````'5Q@\1,6UY?7<.0C;0F`````(/L
M#%7H]\;__XM,)!B)1"0<B0PDB4PD&.CCQO__BU0D'(U$`@*)!"3H<\;__X/$
M#(M,)`Q1:`K@!`A5:##A!`AJ_VH!4(E$)"CHLLC__X/$((M4)`B)^.@4\O__
MZ53____H2L7__XUV`(V\)P````!55U93@>PL@0``BX0D0($``(U4)"S'1"0P
M"N$$",=$)#3RWP0(QT0D.`````#'1"1(H.`$",=$)$R9X`0(B40D$,=$)%`/
MX00(9:$4````B80D'($``#'`N/3?!`C'1"14MN`$",=$)%@7X00(QT0D7```
M``#'1"0\_N`$",=$)$`;X00(QT0D1`````#H/O#__X7`=`F`.``/A?D#``#H
M_/W__X7`B<,/A`L$``"#[`Q3Z-G%__^-1``!@\00@^P,4.AIQ?__@\00@#L`
MB<:)QW0ID(UT)@`/M@.#[`R#PP%0:"3A!`AJ_VH!5X/'`NB<Q___@\0@@#L`
M==R-?"1,N*#@!`CK$XGVC;PG`````(/'!(M'_(7`=#:-5"0LZ*WO__^%P(G#
M=.>`.`!TXNBM]?__A<!TV8/L#%/HP,7__X/$$(7`B<5U68VT)@````"+7"0P
MA=MT2(`[`+\!````=1;K/(UT)@"+7+PPA=MT,(/'`8`[`'0HB=CH8?7__X7`
M=.6#[`Q3Z'3%__^#Q!"%P'35B<7K"XGVC;PG`````#'M@^P,B?-5Z./$__^#
MQ!"+"X/#!(V1__[^_O?1(<J!XH"`@(!TZ8G7P>\0]\*`@```#T37C7L"B=$/
M1-\`T8/;`X/L#"GSC9P#!`0``%/H/,3__XE$)!Q6B<9H*>$$"&@,X`0(56@N
MX00(:O]J`5#H>\;__X/$*&C``0``5NC-Q/__@\00@_C_='6#[`S_-5!1!0CH
M!\;__X/$#`7\````4/]T)!1J`^@#QO__@\00A<!T=(/L#/]T)!B+1"0@_S!H
M\.$$"&H!_S5(404(Z(W%__^#Q"`QP(N,)!R!``!E,PT4````#X6P"0``@<0L
M@0``6UY?7<.)]HV\)P````#H>\3__XL`@_@1#X1[____@^P(4/]T)!B+1"0@
M_S!HM.$$".NAC78`@^P,_S50404(Z&K%__^+@`P!``"#Q!`E`/```#T`0```
M#X5E____@^P,_S50404(Z$/%__^+L!0!``#H2,+__X/$$#G&#X5!____@^P,
M_S50404(Z!_%__^+@`P!``"#Q!`E_P$``#W``0``#X4:____@^P,4^CMPO__
MC50D/(G%N-S@!`CH?>W__X/$$(7`#X2R`0``@^P,4.B9P___6UY0BT0D'/\P
MZ!OV__^#Q!"%P(G##X2.`0``@^P,4^@%P___@\00@_@#?BV-=`/\OS?A!`BY
M!0```/.F=1N#^`0/A"T'``"`?`/[+P^$(@<``(VT)@````#H:_K__X7`=1J#
M[`AJ`%/HW,+__XE$)"B#Q!"%P`^%.`$``+K7X`0(N$O@!`@QV^@,[O__Z`?"
M__]H=>$$"%!H#.`$"(MT)!A6:%#A!`AJ_VH!5>AXQ/__@\0@ZS>-=@#H^\+_
M_X,X$75`Z-'!__^#PP&#[`QH=>$$"%-0:`S@!`A6:%[A!`AJ_VH!5>@_Q/__
M@\0P@^P(:,`!``!5Z(["__^#Q!"#^/]TMH/L#/]T)!CH6L#__XGJN/3?!`CH
M?NW__XDL).A&^O__@\00B>CIY/W__XUT)@"#[`Q0B40D'.@K^O__BT0D'(D$
M).A/PO__@\00Z;_]__^^`0```+C^X`0(ZPZ-=@"+1+0\@\8!A<!T*8U4)"SH
M].O__X7`=.B`.`!TXX/L#%#H$L+__X/$$(7`=-.)P^FR^___N`T```"[`^$$
M".FS^___D(UT)@"+1"00BQCI9_[__VH":O]J[HMT)"16Z,7`__^#Q`QJ!HV$
M)"0!``!05NABO___@\00@+PD'`$```!U#H"\)!T!``!##X1(!@``:@!J`&H`
M_W0D).B(P/__QT0D<`$C16?'1"1T`````,=$)'B)J\WOQT0D?`````#'A"2`
M````_MRZF,>$)(0`````````QX0DB````'94,A#'A"2,`````````,>$))``
M``#PX=+#QX0DE`````````#'A"28`````````,>$))P`````````QX0DH```
M``````#'A"2D`````````,>$).@`````````@\00B6PD')"-M"8`````@^P$
M:`"```"-A"0D`0``4/]T)"3H=[[__X/$$(7`B<,/C@,"``"+M"2(````B[PD
MC````(G8F<'@`XE<)!")5"04`?"#_P`/A\,!```YQ@^'NP$``(NT))````"+
MO"24````BU0D%(F$)(@```"+1"00QX0DC``````````/K-`=P>H=`<:+A"38
M````$=>)M"20````B;PDE````(7`#X1;`0``ND````"-C"28````*<(YTXG6
M#T[S@^P$`<A6C8PD)`$``%%0Z`*^__^+A"3H`````?")A"3H````@\00@_A`
M#X46____C80D'`$``"GSC2PPC40D8.C!Q/__D(/[/P^.!@0``(/K0(G?P>\&
MC7<!P>8&`>Z-M"8`````BT4`@\5`B80DF````(M%Q(F$))P```"+1<B)A"2@
M````BT7,B80DI````(M%T(F$)*@```"+1=2)A"2L````BT78B80DL````(M%
MW(F$)+0```"+1>")A"2X````BT7DB80DO````(M%Z(F$),````"+1>R)A"3$
M````BT7PB80DR````(M%](F$),P```"+1?B)A"30````BT7\B80DU````(U$
M)&#H],/__SGN#X5,____P><&*?MJ1%-6C80DI````%#H5K[__XF<).@```"#
MQ!#I!_[__XVT)@````"-K"0<`0``Z?3^__^-="8`B[0DD````(N\))0```"#
MQ@&#UP#I.O[__XML)!R#[`S_="0DZ!?`__^+A"2@````BYPDF````(NT))P`
M``"+E"2D````B40D((G8#ZSP`XE4)"2#X#^-4`'&A`2H````@(/$$(/Z.`^/
MF0(``+@X````C8PDF````"G0`<J#^`0/@[\"``"%P'0+J`+&`@`/A7L#``"+
M5"04BT0D$(V\)/,```"(G"37````#ZS0&(M4)!2(A"30````BT0D$`^LT!"+
M5"04B(0DT0```(M$)!`/K-`(B(0DT@````^V1"00B(0DTP```(G8#ZSP&(B$
M)-0```")V`^L\!"(A"35````B=@/K/`(B(0DU@```(U$)&#HF,+__XM,)&"+
M7"1DB<Z(C"3B````#ZS>&(GPB<X/K-X0B(0DWP```(GRB<Z+3"1H#ZS>"(B4
M).````")\XG.B(PDY@```(B<).$```"+7"1L#ZS>&(GRB<X/K-X0B)0DXP``
M`(GRB<Z+3"1P#ZS>"(B4).0```")\XG.B(PDZ@```(B<).4```"+7"1T#ZS>
M&(GRB<X/K-X0B)0DYP```(GRB<Z+3"1X#ZS>"(B4).@```")\XG.B(PD[@``
M`(B<).D```"+7"1\#ZS>&(GRB<X/K-X0B)0DZP```(GRB<Z+C"2`````#ZS>
M"(B4).P```")\XG.B(PD\@```(B<).T```"+G"2$````#ZS>&(GRB<X/K-X0
MB)0D[P```(GRB<X/K-X(B)0D\````(GSC;0DX````(B<)/$```"-G"0;`0``
MZ0D```"-=@`/M@:#Q@&#[`P/ML!0:"3A!`AJ_VH!5X/'`NCQO?__@\0@.?MU
MVL:$)!L!````:'7A!`B-A"3W````4&@,X`0(_W0D&&A!X00(:O]J`57HO;W_
M_X/$(.F/^?__BT0D$(M0!(72#X36^/__@^P,4HE4)"#HF;O__X/$$(/X`P^&
MO?C__XM4)!"_/.$$"+D%````C70"_/.F#T3:Z:'X__^)[NG#_/__C8PDF```
M`+A``````=$IT(G"=`TQP,8$`0"#P`$YT'+UC40D8(V\))@```#H><#__[D.
M````,<#SJ^E0_?__C4H$QP(`````QT0"_`````"#X?PIR@'"@^+\@_H$#X(L
M_?__@^+\,<#'!`$`````@\`$.=!R\ND4_?__@+PD'@$``$$/A:KY__^`O"0?
M`0``0P^%G/G__X"\)"`!``!(#X6.^?__@+PD(0$``$4/A8#Y__]J`FK_:L:+
M="0D5N@'NO__@\0,:BF-A"0D`0``4%;HI+C__VAUX00(C80D,`$``%!H#.`$
M"/]T)"AH0>$$"&K_:@%5Z&^\__^#Q##I0?C__XVT)@`````Q_V:)?`+^Z7G\
M___H_[C__^L-D)"0D)"0D)"0D)"0D%575E.#["AEH10```")1"08,<#_-5!1
M!0CHTKO__XU4)!C&0&$!N"_@!`CH4.3__X/$$(7`=`F`.#$/A%`"``#HV^__
M_X/L#/\U4%$%".B=N___:@MJ`6AOX00(4.B.N?__@\0@A<`/A+,```"#/8AA
M!0@!BT`,BW@8#XZ@````,?:[`0```.LQC;0F`````(M%#(/L"%"AA&$%"/\T
MF.B<M___@\00A<!U9:&(804(@\,!@\8!.=A^6X/L#/\U4%$%".@HN___:@!6
M5U#HCKK__X/$((7`=#>+*(M%""4`!"``/0`$``!TIH/L#/\U4%$%".CXNO__
M:@)J`%50Z%VX__^#Q"#KBY"-M"8`````H8AA!0B-4/\Y\@^$,`$``(/L#/\U
M4%$%".C"NO__:@-J`6ATX00(4.BSN/__@\0@A<")PW0TBT`,@^P,BS#_-5!1
M!0CHE[K__X/$#&AVX00(5E#HZ+?__XM##(/$$(L8]D,*0`^%$`(``(/L#/\U
M4%$%".AHNO__:@-J`6A[X`0(4.A9N/__@\0@A<")QG0YC50D"+C]WP0(Z-+B
M__^%P(G##X1H`0``BT8,@^P,BSC_-5!1!0CH);K__X/$#%-74.AZM___@\00
M@^P,_S50404(Z`FZ__^-5"08QD!A`+CTWP0(Z(?B__^#Q!"%P(G#HXQA!0@/
MA)4```"#[`AHP`$``%#HA[C__XU0`8/$$(/Z`78)@_@1#X6.`0``BT0D#&4S
M!10````/A7@!``"#Q!Q;7E]=PXUV`(V\)P````"#^`$/CL?^__^[`0```&:0
M@^P,_S50404(@\,!Z'^Y__]>75=0Z":V__^#Q!`Y'8AA!0A_V^F6_O__C;8`
M````@'@!``^$J_W__^FA_?__D(/L#/\UA&$%".@"\?__@\00A<"CC&$%"`^$
MZP```(M&#(L]A&$%"(L8BT,()0`$(``]``0```^%C0```(M##(/L"%=0Z$>V
M__^)QXM&#(/$$(L8BT,()0`$(``]``0``'5)BT,,5U"AA&$%"/\P:&CB!`CH
M:+?__Y"-M"8`````H81A!0B#[`R+.(M&#(L8_S50404(Z+:X__^)^HG8Z.WG
M__^#Q!#ICO[__X/L#/\U4%$%".B7N/__:@)J`%-0Z/RU__^#Q"#KG(/L#/\U
M4%$%".AYN/__:@)J`%-0Z-ZU__^#Q"#I5?___X/L#/\U4%$%".A8N/__6EE3
M4.A?M___@\00Z=']__^#[`QH1.($".C*MO__Z#6U__]0H81A!0A3_S!HD.($
M".BRMO__9I!64X/L$(MT)!Q6Z%'K__\/MA"#Q!")PX32=!6-0`%FD(#Z+P^V
M$`]$V(/``832=?#HV^W__X7V=!Z%P'0:@#X`=!6#[`AH*>$$"%/H$+3__X/$
M$#G8=`:#Q`1;7L.#Q`2)\%M>Z9?C__^-M"8`````@^P8_S50404(Z**W__]:
M66K_4.@HM?__6/\U4%$%".B,M___@\0,:@!HH,,$"%#H3+?__X/$',-FD&:0
M9I!FD%/H*KK__X'#"G$``(/L"/^S&`$``/]T)!S_="0<_W0D'.CJM/__@\08
M6\-FD&:0D%57,?]64^CUN?__@</5<```@^P,BVPD((VS_/[__^@IL___C8/X
M_O__*<;!_@*%]G0CC;8`````@^P$_W0D+/]T)"Q5_Y2[^/[__X/'`8/$$#GW
M=>.#Q`Q;7E]=PXUV`//#``!3@^P(Z).Y__^!PW-P``"#Q`A;PP,````!``(`
M)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`"X`4$%27U1%
M35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4
M`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.
M`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?
M1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q)
M0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52`%-94U1%
M30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E
M<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S
M=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM`````%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P```"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C
M=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E
M($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R
M7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!8
M6%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER
M*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T
M;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M
M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V
M+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S
M*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%
M3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6
M(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%2
M1T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R
M("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?
M+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@
M-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ
M92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O
M<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@
M)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@
M)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL
M87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S
M970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@
M)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O
M9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S
M970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT
M+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.
M5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I
M<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]
M("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E
M("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<
M-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@
M=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]('-O<G0@>PIL96YG=&@H)&(I(#P]
M/B!L96YG=&@H)&$I"GT@9W)E<"!["B$O0E-$4$%.+PI](&=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*;7D@)69I;&5S.PHO7E\\*"XK*20O(&%N9"`M92`D,2!A
M;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*)&9I;&5S>R1??2LK(&9O
M<B!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI
M('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N
M*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA
M<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2![
M"FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A
M;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B
M(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@
M1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A
M(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)
M3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*
M)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N
M=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I
M.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I
M*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D
M9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2
M+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I
M92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````````@/__
M_\]!`1L#.^@````<````$'+__P0!``!0=O__\`T``'!Y__\H`0``<)[__VP!
M```@G___T`$``*"?___T`0``P*'__W0"```@H___+`,``("D__^X`P``(*7_
M_Q0$``#@I?__L`0``!"F___8!```8*;__Q`%```@I___G`4``#"G__^P!0``
M\*C__ZP&```@J?__P`8``!"J__\@!P``T*O__U`'``!`K/__;`<``'"L__^0
M!P``H*W__P`(``#PN?__W`L``,"]__]L#0``,+[__[@-``!POO__,`X``*"^
M__]<#@```+___Z@.```4``````````%Z4@`!?`@!&PP$!(@!```@````'```
M``1Q__\P!`````X(1@X,2@\+=`1X`#\:.RHR)")`````0````$!X___S)```
M`$$."(4"00X,AP-$#A"&!$$.%(,%1@Z@!@/<)`H.%$'##A!!Q@X,0<<."$'%
M#@1!"P```&````"$````_)S__Z8`````20X(A0)!#@R'`T$.$(8$00X4@P5#
M#C`"1`XT00XX00X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%#@1%"UH.%$7#
M#A!!Q@X,0<<."$'%#@0````@````Z````$B=__]R`````$$."(,"10X@`F4*
M#@A!PPX$00M\````#`$``*2=__\8`@```$$."(4"00X,AP-##A"&!$$.%(,%
M10Y,5PY02`Y`6`Y,0PY02`Y``DL.3$<.4$H.0`)T"@X40<,.$$'&#@Q!QPX(
M0<4.!$<+`E`.2$$.3$$.4$@.0&T.3$L.4$@.0$X.1$$.2$D.3$4.4$P.0```
M`+0```",`0``1)___U8!````00X(A0)!#@R'`T$.$(8$00X4@P5(#J`!;`H.
M%$'##A!!Q@X,0<<."$'%#@1$"T,.K`%!#K`!2`Z@`4\.K`%!#K`!2`Z@`5<.
MK`%$#K`!9`ZL`4$.J`%!#JP!00ZP`44.M`%"#K@!0@Z\`4$.P`%(#J0!10ZH
M`4$.K`%"#K`!2`Z@`5@.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`78.K`%!#K`!
M4`Z@`0"(````1`(``.R?__]=`0```$$."(8"00X,@P-##AQ&#B!,#AQ)#B!*
M#AQ&#B!9#AQ&#B!/#AQ&#B!(#A1"#AA%#AQ!#B!)#AQ&#B!/#AQ&#B!/#AQ&
M#B!,#AQ)#B!.#A!)#AQ&#B!.#A!&#AQ)#B!6#AQ&#B!6#AQ&#B!,#AQ)#B!1
M#@Q!PPX(0<8.!%@```#0`@``P*#__Y$`````00X(@P)%#AQ&#B!(#A1&#AA!
M#AQ"#B!(#A!'"@X(0\,.!$$+0PX<1@X@3@X03PX<1@X@3@X03PX80@X<00X@
M2`X02`X(1,,.!```F````"P#```$H?__NP````!!#@B%`D$.#(<#0PX0A@1!
M#A2#!4@.M"!4#K@@10Z\($4.P"!(#K`@4PZT($$.N"!"#KP@00[`($@.L"!'
M#KP@1@[`($8.Q"!!#L@@00[,($$.T"!(#K`@5@H.%$'##A!!Q@X,0<<."$'%
M#@1%"TL.O"!&#L`@2`ZT($$.N"!!#KP@00[`($@.L"``)````,@#```HH?__
M)P````!##AQ&#B!*#B1%#BA%#BQ!#C!(#@0``#0```#P`P``,*'__T0`````
M0PX<1@X@3@X<1@X@1@X<00X80@X<10X@10XD10XH10XL00XP2`X$B````"@$
M``!(H?__L0````!!#@B'`D$.#(8#00X0@P1&#J!`5PZH0$4.K$!!#K!`10ZT
M0$4.N$!"#KQ`10[`0$@.H$!'#J1`10ZH0$@.K$!!#K!`2`Z@0$P.K$!!#K!`
M2`Z@0$D.I$!!#JA`00ZL0$$.L$!,#J!`6`H.$$'##@Q!Q@X(0<<.!$0+```0
M````M`0``'RA__\%`````````/@```#(!```>*'__[@!````00X(A0)!#@R'
M`T$.$(8$00X4@P5&#L`@;@[(($0.S"!!#M`@2`[`(&P*#A1!PPX00<8.#$''
M#@A!Q0X$00M##LP@00[0($8.S"!!#L@@20[,($$.T"!(#L`@;`[(($$.S"!!
M#M`@2`[`($L.S"!!#M`@2`[`(&P.Q"!!#L@@10[,($$.T"!%#M0@10[8($(.
MW"!!#N`@2`[,($8.T"!(#L0@1@[(($$.S"!"#M`@2`[`($<.S"!&#M`@3@[`
M($\.R"!%#LP@0@[0($@.P"!*#L@@0@[,($$.T"!(#L`@4P[,($$.T"!(#L`@
M`!````#$!0``/*+__R(`````````7````-@%``!8HO__YP````!!#@B#`D,.
M(%8.+$$.,$P.(&P.+$(.,$@.($\*#@A!PPX$0PM@"@X(0<,.!$\+80XD00XH
M00XL10XP2`X@2`H."$'##@1'"T,."$/##@0`+````#@&``#HHO__MP$```!!
M#@B'`D$.#(8#0PY``UL!"@X,0<8."$''#@1&"P``&````&@&``!XI/__:0``
M``!##B!F"@X$1PL``"````"$!@``S*3__R0`````0PX02`X<00X@2`X020H.
M!$,+`&P```"H!@``V*3__R8!````00X(A0)!#@R'`T8.$(8$00X4@P5(#F`"
M4@YH00YL00YP3`Y@`D(*#A1!PPX00<8.#$''#@A!Q0X$20M##FQ!#G!L#F1%
M#FA%#FQ!#G!%#G1"#GA"#GQ!#H`!3`Y@``#8`P``&`<``)BE__]!#````$$.
M"(4"00X,AP-!#A"&!$$.%(,%1@[`@@("IP[,@@)!#M""`DP.P(("0P[,@@)!
M#M""`D@.P(("5`[,@@)$#M""`D4.U(("0@[8@@)"#MR"`D$.X(("2P[`@@("
M0P[,@@)!#M""`D@.P(("`D,.S(("00[0@@)(#L""`E8.S(("0P[0@@)(#L""
M`G4.S(("2@[0@@)*#M2"`D<.V(("10[<@@)!#N""`D4.Y(("0@[H@@)"#NR"
M`D$.\(("2`[(@@)%#LR"`D$.T(("2`[`@@)(#LR"`D8.T(("2`[$@@)&#LB"
M`D0.S(("0@[0@@)(#L""`D<.S(("1`[0@@)&#M2"`D4.V(("0@[<@@)&#N""
M`D@.P(("7`H.%$'##A!!Q@X,0<<."$'%#@1*"U,*#LB"`D$.S(("1`[0@@)&
M#M2"`D4.V(("10M##LR"`D8.T(("3@[`@@)3#LR"`D8.T(("4P[`@@)+#LR"
M`D8.T(("3@[`@@)3#LR"`D$.T(("6`[`@@)+#LR"`D$.T(("1@[,@@)!#LB"
M`D$.S(("1@[0@@)(#L""`DT.S(("00[0@@)(#L""`GX.R(("0@[,@@)!#M""
M`DP.P(("8P[$@@)!#LB"`D4.S(("10[0@@)%#M2"`D(.V(("0@[<@@)!#N""
M`D@.P(("6@[,@@)%#M""`D$.U(("00[8@@)%#MR"`D$.X(("10[D@@)"#NB"
M`D(.[(("00[P@@)(#L""`D,.R(("10[,@@)!#M""`D@.P(("2`[,@@)$#M""
M`EP.P(("3@[,@@)!#M""`E@.P(("=`[,@@)!#M""`D@.P((";`[$@@)"#LB"
M`D(.S(("10[0@@)(#L2"`D(.R(("2`[,@@)!#M""`D@.P(("6@[$@@)"#LB"
M`D(.S(("1`[0@@("H0[`@@)/#L2"`D4.R(("2`[,@@)$#M""`D@.P(("`J$.
MQ(("0P[(@@)(#LR"`D$.T(("6`[`@@("^@[$@@)!#LB"`D$.S(("2`[0@@)/
M#L""`GP.S(("1`[0@@("0`[`@@(#!0(.S(("1`[0@@)%#M2"`D(.V(("0@[<
M@@)!#N""`DL.P(("40[$@@)(#LB"`D4.S(("1`[0@@)%#M2"`D(.V(("0@[<
M@@)!#N""`D@.P(("5P[,@@)!#M""`DP.P(("`N$.Q(("0@[(@@)"#LR"`D4.
MT(("2`[$@@)"#LB"`D@.S(("00[0@@)*#M2"`D@.V(("10[<@@)$#N""`D4.
MY(("0@[H@@)"#NR"`D$.\(("2`[`@@(`C`$``/0*```,KO__S@,```!!#@B%
M`D$.#(<#00X0A@1!#A2#!4,./%(.0%H.,%4./$8.0$<.1$(.2$4.3$$.4$@.
M,'$..$$./$@.0$@.,%8./$8.0$<.1$$.2$$.3$$.4$@.,%@./$8.0$<.1$(.
M2$$.3$$.4$@.,%T./$8.0$<.1$(.2$4.3$$.4$@.,$P./$@.0$@.-$4..$$.
M/$$.0$L.,$\./$8.0$<.1$(.2$4.3$$.4$@.,&0./$@.0$@.-$$..$$./$$.
M0$@.,$,./$8.0%H.,%(..$4./$$.0$L.,&(*#A1!PPX00<8.#$''#@A!Q0X$
M2PM3#CQ&#D!)#CQ!#CA!#CQ!#D!(#C!F#CQ&#D!(#C!Q#CA!#CQ!#D!-#C!5
M"@XT00XX1PX\10Y`30M(#CQ-#D!1#C!(#CQ&#D!'#D1"#DA!#DQ!#E!(#C!%
M#CQ&#D!'#D1"#DA!#DQ!#E!(#C!(#CQ&#D!&#CQ!#CA!#CQ!#D!(#C!("@X\
M10Y`10M&#C1&#CA"#CQ%#D```$@```"$#```3+#__VD`````00X(A@)!#@R#
M`T,.'$4.($L.$'`.&$4.'$$.($@.$$<*#@Q!PPX(0<8.!$$+0PX,0\,."$'&
M#@0````T````T`P``'"P__\X`````$,.'$8.($8.'$$.&$(.'$$.($8.'$8.
M($@.%$(.&$4.'$$.($@.!#P````(#0``6&C__R("````1`P!`$<0!0)U`$4/
M`W5T!A`&`G5\$`,"=7@#HP$*P0P!`$'#0<9!Q4,,!`1!"P`H````2`T``#BP
M__\K`````$$."(,"3@X01@X41`X81`X<1`X@2`X(0<,.!$@```!T#0``/+#_
M_UT`````00X(A0)!#@R'`T,.$(8$00X4@P5.#B!G#B1$#BA$#BQ!#C!-#B!'
M#A1!PPX00<8.#$''#@A!Q0X$```0````P`T``%"P__\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````P)D$"*"9!`@``````0````$````!````!0(`
M``$```!4`@``#````&R2!`@-````A-\$"!D```#X3@4(&P````0````:````
M_$X%"!P````$````]?[_;ZR!!`@%````J(D$"`8````(@P0("@```!T%```+
M````$````!4``````````P````!0!0@"````$`(``!0````1````%P```%R0
M!`@1````+)`$"!(````P````$P````@```#^__]OG(\$"/___V\"````\/__
M;\:.!`@`````````````````````````````````````````````````````
M````````````````!$\%"```````````II($"+:2!`C&D@0(UI($".:2!`CV
MD@0(!I,$"!:3!`@FDP0(-I,$"$:3!`A6DP0(9I,$"':3!`B&DP0(EI,$"*:3
M!`BVDP0(QI,$"-:3!`CFDP0(]I,$"`:4!`@6E`0()I0$"#:4!`A&E`0(5I0$
M"&:4!`AVE`0(AI0$"):4!`BFE`0(MI0$",:4!`C6E`0(YI0$"/:4!`@&E00(
M%I4$"":5!`@VE00(1I4$"%:5!`AFE00(=I4$"(:5!`B6E00(II4$"+:5!`C&
ME00(UI4$".:5!`CVE00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6
M!`B&E@0(EI8$"*:6!`BVE@0(``````````#_____U.($"$=#0SH@*%5B=6YT
M=2`U+C(N,2TR-G5B=6YT=3$I(#4N,BXQ(#(P,34Q,3(U`$=#0SH@*%5B=6YT
M=2`T+CDN,BTQ,'5B=6YT=3$Q*2`T+CDN,@``+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M``L````!`````@```%2!!`A4`0``$P```````````````0`````````3````
M!P````(```!H@00(:`$``"````````````````0`````````(0````<````"
M````B($$"(@!```D```````````````$`````````#0```#V__]O`@```*R!
M!`BL`0``7`$```4`````````!`````0````^````"P````(````(@P0("`,`
M`*`&```&`````0````0````0````1@````,````"````J(D$"*@)```=!0``
M```````````!`````````$X```#___]O`@```,:.!`C&#@``U`````4`````
M`````@````(```!;````_O__;P(```"<CP0(G`\``)`````&`````@````0`
M````````:@````D````"````+)`$""P0```P````!0`````````$````"```
M`',````)````0@```%R0!`A<$```$`(```4````8````!`````@```!\````
M`0````8```!LD@0(;!(``",```````````````0`````````=P````$````&
M````D)($")`2```P!``````````````0````!````((````!````!@```,"6
M!`C`%@``"```````````````"`````````"+`````0````8```#0E@0(T!8`
M`+)(`````````````!``````````D0````$````&````A-\$"(1?```4````
M```````````$`````````)<````!`````@```)C?!`B87P``Z$``````````
M````"`````````"?`````0````(```"`(`4(@*```.P```````````````0`
M````````K0````$````"````;"$%"&RA``#4#0`````````````$````````
M`+<````.`````P```/A.!0CXO@``!```````````````!`````````##````
M#P````,```#\3@4(_+X```0```````````````0`````````SP````$````#
M`````$\%"`"_```$```````````````$`````````-0````&`````P````1/
M!0@$OP``^`````8`````````!`````@```"&`````0````,```#\3P4(_+\`
M``0```````````````0````$````W0````$````#`````%`%"`#````4`0``
M```````````$````!````.8````!`````P```!11!0@4P0``$```````````
M````!`````````#L````"`````,```!`404(),$``%00`````````````"``
M````````\0````$````P`````````"3!``!2```````````````!`````0``
I``$````#``````````````!VP0``^@```````````````0``````````
